@@ -1,4 +1,4 @@
-// Copyright 2018-2020 Cargill Incorporated
+// Copyright 2018-2021 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -13,11 +13,9 @@
 // limitations under the License.
 
 use super::schema::user_credentials;
-use crate::biome::user::store::diesel::models::UserModel;
 
 #[derive(Queryable, Identifiable, Associations, PartialEq, Debug)]
 #[table_name = "user_credentials"]
-#[belongs_to(UserModel, foreign_key = "user_id")]
 pub struct CredentialsModel {
     pub id: i64,
     pub user_id: String,
