@@ -14,8 +14,8 @@
 
 #[cfg(feature = "diesel")]
 pub mod diesel;
-/// NodeIdStore error types
 pub mod error;
+pub mod file;
 
 use error::NodeIdStoreError;
 
