@@ -121,14 +121,21 @@ impl PeerManagerConnector {
     /// # Arguments
     ///
     /// * `endpoint` - The endpoint associated with the peer.
+    /// * `local_authorization` - The required PeerAuthorizationToken that will be used to identify
+    /// *  the local node.
     pub fn add_unidentified_peer(
         &self,
         endpoint: String,
+        #[cfg(feature = "challenge-authorization")] local_authorization: PeerAuthorizationToken,
     ) -> Result<EndpointPeerRef, PeerUnknownAddError> {
         let (sender, recv) = channel();
 
-        let message =
-            PeerManagerMessage::Request(PeerManagerRequest::AddUnidentified { endpoint, sender });
+        let message = PeerManagerMessage::Request(PeerManagerRequest::AddUnidentified {
+            endpoint,
+            #[cfg(feature = "challenge-authorization")]
+            local_authorization,
+            sender,
+        });
 
         match self.sender.send(message) {
             Ok(()) => (),
@@ -153,14 +160,14 @@ impl PeerManagerConnector {
         match self.sender.send(message) {
             Ok(()) => (),
             Err(_) => {
-                return Err(PeerListError::InternalError(
+                return Err(PeerListError::Internal(
                     "Unable to send message to PeerManager, receiver dropped".to_string(),
                 ))
             }
         };
 
         recv.recv()
-            .map_err(|err| PeerListError::ReceiveError(format!("{:?}", err)))?
+            .map_err(|err| PeerListError::Receive(format!("{:?}", err)))?
     }
 
     /// Requests the list of unreferenced peers.
@@ -176,14 +183,14 @@ impl PeerManagerConnector {
         match self.sender.send(message) {
             Ok(()) => (),
             Err(_) => {
-                return Err(PeerListError::InternalError(
+                return Err(PeerListError::Internal(
                     "Unable to send message to PeerManager, receiver dropped".to_string(),
                 ))
             }
         };
 
         recv.recv()
-            .map_err(|err| PeerListError::ReceiveError(format!("{:?}", err)))?
+            .map_err(|err| PeerListError::Receive(format!("{:?}", err)))?
     }
 
     /// Requests the map of currently connected peers to connection IDs
@@ -366,14 +373,14 @@ impl PeerRemover {
         match self.sender.send(message) {
             Ok(()) => (),
             Err(_) => {
-                return Err(PeerRefRemoveError::InternalError(
+                return Err(PeerRefRemoveError::Internal(
                     "Unable to send message to PeerManager, receiver dropped".to_string(),
                 ))
             }
         };
 
         recv.recv()
-            .map_err(|err| PeerRefRemoveError::ReceiveError(format!("{:?}", err)))?
+            .map_err(|err| PeerRefRemoveError::Receive(format!("{:?}", err)))?
     }
 
     /// Sends a request to the `PeerManager` to remove a peer by its endpoint.
@@ -393,14 +400,14 @@ impl PeerRemover {
         match self.sender.send(message) {
             Ok(()) => (),
             Err(_) => {
-                return Err(PeerRefRemoveError::InternalError(
+                return Err(PeerRefRemoveError::Internal(
                     "Unable to send message to PeerManager, receiver dropped".to_string(),
                 ))
             }
         };
 
         recv.recv()
-            .map_err(|err| PeerRefRemoveError::ReceiveError(format!("{:?}", err)))?
+            .map_err(|err| PeerRefRemoveError::Receive(format!("{:?}", err)))?
     }
 }
 
