@@ -51,8 +51,7 @@ pub struct PeerMetadata {
     /// How long to wait before trying to reconnect to a peer
     pub retry_frequency: u64,
     /// The required way the local node must be identified, this is required on retry
-    #[cfg(feature = "challenge-authorization")]
-    pub required_local_auth: Option<PeerAuthorizationToken>,
+    pub required_local_auth: PeerAuthorizationToken,
 }
 
 /// A map of peer IDs to peer metadata, which also maintains a redirect table for updated peer IDs.
@@ -63,6 +62,8 @@ pub struct PeerMap {
     // Endpoint to peer id
     endpoints: HashMap<String, PeerAuthorizationToken>,
     initial_retry_frequency: u64,
+    #[cfg(not(feature = "challenge-authorization"))]
+    local_identity: PeerAuthorizationToken,
 }
 
 impl PeerMap {
@@ -71,7 +72,12 @@ impl PeerMap {
     /// # Arguments
     ///
     /// * `initial_retry_frequency` - The value to set as the retry frequency for a new peer
-    pub fn new(initial_retry_frequency: u64) -> Self {
+    /// * `local_identity` - The default required local authorization if the
+    ///  `challenge-authorization` features is not enabled
+    pub fn new(
+        initial_retry_frequency: u64,
+        #[cfg(not(feature = "challenge-authorization"))] local_identity: PeerAuthorizationToken,
+    ) -> Self {
         // initialize peers metric
         gauge!("splinter.peer_manager.peers", 0);
 
@@ -79,6 +85,8 @@ impl PeerMap {
             peers: HashMap::new(),
             endpoints: HashMap::new(),
             initial_retry_frequency,
+            #[cfg(not(feature = "challenge-authorization"))]
+            local_identity,
         }
     }
 
@@ -116,9 +124,7 @@ impl PeerMap {
         endpoints: Vec<String>,
         active_endpoint: String,
         status: PeerStatus,
-        #[cfg(feature = "challenge-authorization")] required_local_auth: Option<
-            PeerAuthorizationToken,
-        >,
+        #[cfg(feature = "challenge-authorization")] required_local_auth: PeerAuthorizationToken,
     ) {
         let peer_metadata = PeerMetadata {
             id: peer_id.clone(),
@@ -130,6 +136,8 @@ impl PeerMap {
             retry_frequency: self.initial_retry_frequency,
             #[cfg(feature = "challenge-authorization")]
             required_local_auth,
+            #[cfg(not(feature = "challenge-authorization"))]
+            required_local_auth: self.local_identity.clone(),
         };
 
         self.peers.insert(peer_id.clone(), peer_metadata);
@@ -149,7 +157,7 @@ impl PeerMap {
     ///
     /// Returns the metadata for the peer if it exists.
     pub fn remove(&mut self, peer_id: &PeerAuthorizationToken) -> Option<PeerMetadata> {
-        if let Some(peer_metadata) = self.peers.remove(&peer_id) {
+        if let Some(peer_metadata) = self.peers.remove(peer_id) {
             for endpoint in peer_metadata.endpoints.iter() {
                 self.endpoints.remove(endpoint);
             }
@@ -229,7 +237,11 @@ pub mod tests {
     //  3. Update the first peer and test the updated peer id is returned in place of the old id.
     #[test]
     fn test_get_peer_ids() {
-        let mut peer_map = PeerMap::new(10);
+        let mut peer_map = PeerMap::new(
+            10,
+            #[cfg(not(feature = "challenge-authorization"))]
+            PeerAuthorizationToken::from_peer_id("my_id"),
+        );
 
         let peers = peer_map.peer_ids();
         assert_eq!(peers, Vec::<PeerAuthorizationToken>::new());
@@ -243,7 +255,7 @@ pub mod tests {
             "test_endpoint2".to_string(),
             PeerStatus::Connected,
             #[cfg(feature = "challenge-authorization")]
-            None,
+            PeerAuthorizationToken::from_peer_id("my_id"),
         );
 
         peer_map.insert(
@@ -255,7 +267,7 @@ pub mod tests {
             "next_endpoint1".to_string(),
             PeerStatus::Connected,
             #[cfg(feature = "challenge-authorization")]
-            None,
+            PeerAuthorizationToken::from_peer_id("my_id"),
         );
 
         let mut peers = peer_map.peer_ids();
@@ -278,7 +290,11 @@ pub mod tests {
     //  2. Add two peers and test that their ids are returned from connection_ids()
     #[test]
     fn test_get_connection_ids() {
-        let mut peer_map = PeerMap::new(10);
+        let mut peer_map = PeerMap::new(
+            10,
+            #[cfg(not(feature = "challenge-authorization"))]
+            PeerAuthorizationToken::from_peer_id("my_id"),
+        );
 
         let peers = peer_map.peer_ids();
         assert_eq!(peers, Vec::<PeerAuthorizationToken>::new());
@@ -292,7 +308,7 @@ pub mod tests {
             "test_endpoint2".to_string(),
             PeerStatus::Connected,
             #[cfg(feature = "challenge-authorization")]
-            None,
+            PeerAuthorizationToken::from_peer_id("my_id"),
         );
 
         peer_map.insert(
@@ -304,7 +320,7 @@ pub mod tests {
             "next_endpoint1".to_string(),
             PeerStatus::Connected,
             #[cfg(feature = "challenge-authorization")]
-            None,
+            PeerAuthorizationToken::from_peer_id("my_id"),
         );
 
         let peers = peer_map.connection_ids();
@@ -330,7 +346,11 @@ pub mod tests {
     //  4. Validate same metadata is returned from get_peer_from_endpoint("test_endpoint2")
     #[test]
     fn test_get_peer_by_endpoint() {
-        let mut peer_map = PeerMap::new(10);
+        let mut peer_map = PeerMap::new(
+            10,
+            #[cfg(not(feature = "challenge-authorization"))]
+            PeerAuthorizationToken::from_peer_id("my_id"),
+        );
 
         let peer_metadata = peer_map.get_peer_from_endpoint("bad_endpoint");
         assert_eq!(peer_metadata, None);
@@ -344,7 +364,7 @@ pub mod tests {
             "test_endpoint2".to_string(),
             PeerStatus::Pending,
             #[cfg(feature = "challenge-authorization")]
-            None,
+            PeerAuthorizationToken::from_peer_id("my_id"),
         );
 
         let peer_metadata = peer_map
@@ -376,7 +396,11 @@ pub mod tests {
     //  3. Check that the correct metadata is returned from self.peers.get()
     #[test]
     fn test_insert_peer() {
-        let mut peer_map = PeerMap::new(10);
+        let mut peer_map = PeerMap::new(
+            10,
+            #[cfg(not(feature = "challenge-authorization"))]
+            PeerAuthorizationToken::from_peer_id("my_id"),
+        );
 
         peer_map.insert(
             PeerAuthorizationToken::Trust {
@@ -387,7 +411,7 @@ pub mod tests {
             "test_endpoint2".to_string(),
             PeerStatus::Pending,
             #[cfg(feature = "challenge-authorization")]
-            None,
+            PeerAuthorizationToken::from_peer_id("my_id"),
         );
         assert!(peer_map.peers.contains_key(&PeerAuthorizationToken::Trust {
             peer_id: "test_peer".to_string(),
@@ -419,7 +443,11 @@ pub mod tests {
     //  3. Verify that the correct peer_metadata is returned when removing test_peer
     #[test]
     fn test_remove_peer() {
-        let mut peer_map = PeerMap::new(10);
+        let mut peer_map = PeerMap::new(
+            10,
+            #[cfg(not(feature = "challenge-authorization"))]
+            PeerAuthorizationToken::from_peer_id("my_id"),
+        );
 
         let peer_metdata = peer_map.remove(&PeerAuthorizationToken::Trust {
             peer_id: "test_peer".to_string(),
@@ -436,7 +464,7 @@ pub mod tests {
             "test_endpoint2".to_string(),
             PeerStatus::Pending,
             #[cfg(feature = "challenge-authorization")]
-            None,
+            PeerAuthorizationToken::from_peer_id("my_id"),
         );
         assert!(peer_map.peers.contains_key(&PeerAuthorizationToken::Trust {
             peer_id: "test_peer".to_string()
@@ -470,7 +498,11 @@ pub mod tests {
     //  4. Check that the peer's metadata now points to test_endpoint1 and the peer is disconnected
     #[test]
     fn test_get_update_active_endpoint() {
-        let mut peer_map = PeerMap::new(10);
+        let mut peer_map = PeerMap::new(
+            10,
+            #[cfg(not(feature = "challenge-authorization"))]
+            PeerAuthorizationToken::from_peer_id("my_id"),
+        );
         let no_peer_metadata = PeerMetadata {
             id: PeerAuthorizationToken::Trust {
                 peer_id: "test_peer".to_string(),
@@ -481,8 +513,7 @@ pub mod tests {
             status: PeerStatus::Connected,
             last_connection_attempt: Instant::now(),
             retry_frequency: 10,
-            #[cfg(feature = "challenge-authorization")]
-            required_local_auth: None,
+            required_local_auth: PeerAuthorizationToken::from_peer_id("my_id"),
         };
 
         if let Ok(()) = peer_map.update_peer(no_peer_metadata) {
@@ -498,7 +529,7 @@ pub mod tests {
             "test_endpoint2".to_string(),
             PeerStatus::Connected,
             #[cfg(feature = "challenge-authorization")]
-            None,
+            PeerAuthorizationToken::from_peer_id("my_id"),
         );
         assert!(peer_map.peers.contains_key(&PeerAuthorizationToken::Trust {
             peer_id: "test_peer".to_string(),
